<?php
// Heading
$_['heading_title']     = 'Multi Modules';

// Text
$_['text_extension']   	= 'Extensions';
$_['text_success']     	= 'Success: You have modified multi modules!';
$_['text_edit']        	= 'Edit Multi Modules';
$_['text_column_size']  = 'Column Size';
$_['text_column_image'] = 'Add Banners';
$_['text_new_column']  	= 'New Column';
$_['text_show']  		= 'Show';
$_['text_hide']  		= 'Hide';
$_['text_latest_products']  		= 'Latest Products';
$_['text_bestseller_products']  	= 'Bestseller Products';
$_['text_special_products']  		= 'Special Products';

// Button
$_['button_addcolumn']			= 'Add Column';
$_['button_addcolumn_image']	= 'Add Image';

// Tab
$_['tab_general']		= 'General';
$_['tab_data']			= 'Data';

// Entry
$_['entry_name']       	= 'Module Name';
$_['entry_title']       = 'Title';
$_['entry_width']      	= 'Width';
$_['entry_height']     	= 'Height';
$_['entry_column_size'] = 'Column Size';
$_['entry_width'] 		= 'Width';
$_['entry_height']		= 'Height';
$_['entry_limit']     	= 'Limit';
$_['entry_status']     	= 'Status';
$_['entry_produts']     = 'Produts';
$_['entry_action']     	= 'Action';

// Error
$_['error_warning']     = 'Warning: Please check the form carefully for errors!';
$_['error_permission']  = 'Warning: You do not have permission to modify multi modules!';
$_['error_name']       	= 'Module Name must be between 3 and 64 characters!';
$_['error_title']       = 'Title must be between 3 and 64 characters!';
$_['error_width']      	= 'Width required!';
$_['error_height']     	= 'Height required!';
$_['error_columns']     = 'Column required!';
$_['error_column_value']= 'Banner Images required!';
$_['error_image']		= 'Banner Image required!';