<?php
// Text
$_['error_newsletter_email']  = 'E-Mail Address does not appear to be valid!';
$_['error_email_exists']  =  'Warning: E-Mail Address is already subscribed!';
$_['text_email_success']  = 'Your Email has been successfully submit.';