{% if languages|length > 1 %}
<form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-language">
  <h4>
    {% for language in languages %}
    {% if language.code == code %} 
    <img src="catalog/language/{{ language.code }}/{{ language.code }}.png" alt="{{ language.name }}" title="{{ language.name }}">
    {% endif %}
    {% endfor %}
    {{ text_language }}</span>
  </h4>
    <ul class="list-unstyled">
      {% for language in languages %}
      <li>
        <a class="language-select" type="button" name="{{ language.code }}"><img src="catalog/language/{{ language.code }}/{{ language.code }}.png" alt="{{ language.name }}" title="{{ language.name }}" /> {{ language.name }}</a>
      </li>
      {% endfor %}
    </ul>
  <input type="hidden" name="code" value="" />
  <input type="hidden" name="redirect" value="{{ redirect }}" />
</form>
{% endif %}
