<?php
// Heading
$_['heading_title']          = 'Testimonials';

// Text
$_['text_success']           = 'Success: You have modified testimonials!';
$_['text_list']              = 'Testimonial List';
$_['text_add']               = 'Add Testimonial';
$_['text_edit']              = 'Edit Testimonial';
$_['text_default']           = 'Default';
$_['text_star']           	 = 'Star';

// Column
$_['column_title']           = 'Title';
$_['column_image']	     	 = 'Image';
$_['column_author']	     	 = 'Author';
$_['column_destination']	 = 'Destination';
$_['column_sort_order']	     = 'Sort Order';
$_['column_rating']	 		 = 'Rating';
$_['column_status']	     	 = 'Status';
$_['column_action']          = 'Action';

// Entry
$_['entry_title']            = 'Title';
$_['entry_description']      = 'Description';
$_['entry_destination']      = 'Destination';
$_['entry_author']       	 = 'Author';
$_['entry_rating']       	 = 'Rating';
$_['entry_image']       	 = 'Image';
$_['entry_status']           = 'Status';
$_['entry_sort_order']       = 'Sort Order';

// Error
$_['error_warning']          = 'Warning: Please check the form carefully for errors!';
$_['error_permission']       = 'Warning: You do not have permission to modify information!';
$_['error_title']            = 'Title must be between 3 and 64 characters!';
$_['error_destination']      = 'Destination must be between 2 and 128 characters!';
$_['error_author']           = 'Author must be between 2 and 64 characters!';
