<?php
// Heading
$_['heading_title']    = 'J-Shopping Featured Categories';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified featured categories module!';
$_['text_edit']        = 'Edit Featured Module';

// Entry
$_['entry_name']       = 'Module Name';
$_['entry_category']   = 'Categories';
$_['entry_limit']      = 'Limit';
$_['entry_width']      = 'Width';
$_['entry_height']     = 'Height';
$_['entry_status']     = 'Status';

// Help
$_['help_category']     = '(Autocomplete)';

// Error
$_['error_permission'] = 'Warning: You do not have permission to modify featured categories module!';
$_['error_name']       = 'Module Name must be between 3 and 64 characters!';
$_['error_width']      = 'Width required!';
$_['error_height']     = 'Height required!';