<?php
// Heading
$_['heading_title']			= 'Display Copyright';

// Text
$_['text_extension']   		= 'Extensions';
$_['text_success']     		= 'Success: You have modified custom footer copyright!';
$_['text_edit']        		= 'Edit Custom Footer';
$_['text_control_panel']    = 'Display Copyright Setting';
$_['text_left']				= 'Left';
$_['text_center']			= 'Center';
$_['text_right']			= 'Right';

// Size Class
$_['text_size_1']			= 'col-sm-1';
$_['text_size_2']			= 'col-sm-2';
$_['text_size_3']			= 'col-sm-3';
$_['text_size_4']			= 'col-sm-4';
$_['text_size_5']			= 'col-sm-5';
$_['text_size_6']			= 'col-sm-6';
$_['text_size_7']			= 'col-sm-7';
$_['text_size_8']			= 'col-sm-8';
$_['text_size_9']			= 'col-sm-9';
$_['text_size_10']			= 'col-sm-10';
$_['text_size_11']			= 'col-sm-11';
$_['text_size_12']			= 'col-sm-12';

// Button
$_['button_informationlinks_add']  = 'Add Custom Link';

// Entry
$_['entry_status']     			= 'Status';
$_['entry_logo']     			= 'Display Logo';
$_['entry_background_color']	= 'Background Color';
$_['entry_font_color']			= 'Font Color';
$_['entry_description']			= 'Description';
$_['entry_title']				= 'Title';
$_['entry_url']					= 'URL';
$_['entry_action']				= 'Action';
$_['entry_description_sizeclass'] = 'Description Size Class';
$_['entry_link_sizeclass']		= 'Custom Links Size Class';
$_['entry_textalgin']			= 'Text Align';
$_['entry_copyright_bg']						= 'Copyright Background Color';
$_['entry_copyright_color']						= 'Copyright Text Color';
$_['entry_copyright_links_color']				= 'Copyright Links Color';
$_['entry_copyright_links_hover_color']			= 'Copyright Links Hover Color';

// General
$_['tab_general']					= 'General';
$_['tab_description']				= 'Description';
$_['tab_links']						= 'Custom Links';
$_['tab_colors']					= 'Colors';

// Error
$_['error_permission'] 				= 'Warning: You do not have permission to modify custom footer copyright!';
$_['error_warning']          		= 'Warning: Please check the form carefully for errors!';
$_['error_informationlinks_title']  = 'Title must be greater than 1 and less than 255 characters!';