<div class="search-wrap">
	<button data-toggle="dropdown" type="button" class="dropdown-toggle hidden-sm hidden-xs"><i class="fa fa-search"></i></button>
	<div class="dropdown-menu dropdown-menu-right">
		<div id="search" class="input-group">
		  <input type="text" name="search" value="{{ search }}" placeholder="{{ text_search }}" class="form-control input-lg" />
		  <span class="input-group-btn">
		    <button type="button" class="btn btn-lg"><i class="fa fa-search"></i></button>
		  </span>
		</div>
	</div>
</div>