<?php
// Heading
$_['heading_title']    = 'Top Products';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified Top Products module!';
$_['text_edit']        = 'Edit Top Products Module';

// Entry
$_['entry_name']       = 'Module Name';
$_['entry_product']    = 'Products';
$_['entry_limit']      = 'Limit';
$_['entry_width']      = 'Width';
$_['entry_height']     = 'Height';
$_['entry_status']     = 'Status';
$_['entry_image_size'] = 'Image Dimension <br> (W x H)';
$_['entry_description_limit'] = 'Description Characters Limit';

// Tab
$_['tab_product']   	= 'Product';
$_['tab_testimonial']   = 'Testimonial';

// Help
$_['help_product']     = '(Autocomplete)';

// Error
$_['error_permission'] 		= 'Warning: You do not have permission to modify Top Products module!';
$_['error_name']       		= 'Module Name must be between 3 and 64 characters!';
$_['error_image_size']      = 'Image size required!';
$_['error_warning']         = 'Warning: Please check the form carefully for errors!';