<?php
// Theme Main Menu Text
$_['text_jcirclet_theme']   		= 'ES-Circlet Theme';

// Theme Menu Text
$_['text_jcirclet']   				= 'Banner';

// Footer Menu Text
$_['text_jcirclet_testimonial']		= 'Testimonials';

// Footer Menu Text
$_['text_jcirclet_footer']			= 'Custom Footer';
$_['text_jade_footersetting']		= 'Fotter Setting';
$_['text_jade_customfooter']		= 'Footer Links';
$_['text_jade_footer_copyright']	= 'Display Copyright';
$_['text_jade_footer_newsletter']	= 'Newsletter Subscribers';