<?php
// Link
$_['text_jade_footer']				= 'Custom Footer';
$_['text_jade_footersetting']		= 'Setting';
$_['text_jade_customfooter']		= 'Footer Links';
$_['text_jade_footer_copyright']	= 'Display Copyright';
$_['text_jade_footer_newsletter']	= 'Newsletter Subscribers';