<?php
// Heading
$_['heading_title']          = 'Newsletter Subscribers';

// Text
$_['text_success']           = 'Success: You have modified newsletter subscribers!';
$_['text_list']              = 'Newsletter Subscribers List';
$_['text_edit']              = 'Edit Newsletter Subscriber';
$_['text_default']           = 'Default';
$_['text_newsletter_verified']    	  = 'Verified';
$_['text_newsletter_unsubscriber']    = 'Un-Subscribe';

// Button
$_['button_send_email']    	 = 'Send Email';

// Column
$_['column_email']           = 'Email';
$_['column_status']	     	 = 'Status';
$_['column_action']          = 'Action';
$_['column_ip']      		 = 'IP Address';
$_['column_date_added']      = 'Date Added';

// Entry
$_['entry_email']            = 'Email';
$_['entry_status']           = 'Status';
$_['entry_language']         = 'Language';
$_['entry_store']            = 'Store';

// Error
$_['error_warning']          = 'Warning: Please check the form carefully for errors!';
$_['error_permission']       = 'Warning: You do not have permission to modify newsletter subscribers!';