{% if currencies|length > 1 %}
<form action="{{ action }}" method="post" enctype="multipart/form-data" id="form-currency">
  <h4>
    {% for currency in currencies %}
      {% if currency.symbol_left and currency.code == code %} 
        <strong>{{ currency.symbol_left }}</strong>
        {% elseif currency.symbol_right and currency.code == code %} 
        <strong>{{ currency.symbol_right }}</strong> 
      {% endif %}
    {% endfor %} 
    <span>{{ text_currency }}</span>
  </h4>
  <ul class="list-unstyled">
    {% for currency in currencies %}
      {% if currency.symbol_left %}
        <li>
          <a class="currency-select" type="button" name="{{ currency.code }}">{{ currency.symbol_left }} {{ currency.title }}</a>
        </li>
      {% else %}
        <li>
          <a class="currency-select" type="button" name="{{ currency.code }}">{{ currency.symbol_right }} {{ currency.title }}</a>
        </li>
      {% endif %}
    {% endfor %}
  </ul>
  <input type="hidden" name="code" value="" />
  <input type="hidden" name="redirect" value="{{ redirect }}" />
</form>
{% endif %} 