<?php
// Heading
$_['heading_title']          = 'Custom Footer';

// Text
$_['text_success']           = 'Success: You have modified custom footer!';
$_['text_list']              = 'Custom Footer Links';
$_['text_add']               = 'Add Custom Footer Link';
$_['text_edit']              = 'Edit Custom Footer Link';
$_['text_default']           = 'Default';

// Tab
$_['tab_link']				= 'Link';

// Size Class
$_['text_size_1']			= 'col-sm-1';
$_['text_size_2']			= 'col-sm-2';
$_['text_size_3']			= 'col-sm-3';
$_['text_size_4']			= 'col-sm-4';
$_['text_size_5']			= 'col-sm-5';
$_['text_size_6']			= 'col-sm-6';
$_['text_size_7']			= 'col-sm-7';
$_['text_size_8']			= 'col-sm-8';
$_['text_size_9']			= 'col-sm-9';
$_['text_size_10']			= 'col-sm-10';
$_['text_size_11']			= 'col-sm-11';
$_['text_size_12']			= 'col-sm-12';

// Column
$_['column_title']           = 'Title';
$_['column_sort_order']	     = 'Sort Order';
$_['column_action']          = 'Action';

// Entry
$_['entry_title']            = 'Title';
$_['entry_status']           = 'Status';
$_['entry_sort_order']       = 'Sort Order';
$_['entry_type']       		 = 'Type';
$_['entry_url']       		 = 'URL';
$_['entry_icon']       		 = 'Icon Class';
$_['entry_image']       	 = 'Image';
$_['entry_description']    	 = 'Description';
$_['entry_placeholder']    	 = 'Placeholder';
$_['entry_button_text']    	 = 'Button Text';
$_['entry_hotline_title']    = 'Title';
$_['entry_hotline_description'] = 'Description';
$_['entry_action']           = 'Action';
$_['entry_size_class']       = 'Size Class';
$_['entry_customer_group']   = 'Customer Group';
$_['entry_store']       	 = 'Store';

// Button
$_['button_contactdetail_add'] 		= 'Add Contact Detail';
$_['button_accountlinks_add'] 		= 'Add Account Link';
$_['button_informationlinks_add'] 	= 'Add Information Link';
$_['button_sociallinks_add'] 		= 'Add Social Icon';
$_['button_appicons_add'] 			= 'Add App Icon';

// Text
$_['type_contact_detail']		= 'Contact Detail';
$_['type_newsletter']			= 'Newsletter';
$_['type_account_links']		= 'Account Links';
$_['type_social_icons']			= 'Social Icons';
$_['type_information_links']	= 'Information Links';
$_['type_payments_icons']		= 'Payments Methods Icons';
$_['type_app_icons']			= 'App Icons';
$_['type_editor']				= 'Editor';
$_['type_hotline']				= 'Hot Line';

// Error
$_['error_warning']          		= 'Warning: Please check the form carefully for errors!';
$_['error_permission']       		= 'Warning: You do not have permission to modify custom footer!';
$_['error_title']            		= 'Title must be between 3 and 64 characters!';
$_['error_row_title']				= 'Title must be minimum or grater 3 characters!';