<?php
// Heading
$_['heading_title']     	 = 'Send Email To Newsletter Subscribers';
$_['heading_newsletter']     = 'Newsletter Subscribers';

// Text
$_['text_list']              = 'Newsletter Subscribers List';
$_['text_edit']              = 'Edit Newsletter Subscriber';
$_['text_default']           = 'Default';
$_['text_newsletter_verified']    	  	= 'Verified';
$_['text_newsletter_unsubscriber']    	= 'Un-Subscriber';
$_['text_newsletter']        			= 'Subscribers';
$_['text_success']         				= 'Your message has been successfully sent!';
$_['text_sent']            				= 'Your message has been successfully sent to %s of %s recipients!';

// Entry
$_['entry_email']            = 'Email';
$_['entry_status']           = 'Status';
$_['entry_language']         = 'Language';
$_['entry_store']            = 'Store';
$_['entry_to']            	 = 'To';
$_['entry_subject']          = 'Subject';
$_['entry_message']          = 'Message';
$_['entry_newsletters']      = 'Subscriber Email';

// Help
$_['help_newsletters']	 	 = '(Autocomplete)';

// Error
$_['error_warning']          = 'Warning: Please check the form carefully for errors!';
$_['error_permission']       = 'Warning: You do not have permission to modify send email to newsletter subscribers!';
$_['error_email']        	 = 'No Email Found!';
$_['error_subject']          = 'E-Mail Subject required!';
$_['error_message']          = 'E-Mail Message required!';