<div class="bgblock text-center">
  <h3 class="exheading">{{ heading_title }}</h3>
  <div class="row"> {% for product in products %}
    <div class="product-layout col-lg-3 col-md-3 col-sm-6 col-xs-12">
      <div class="product-thumb transition">
        <div class="image">
          <a href="{{ product.href }}"><img src="{{ product.thumb }}" alt="{{ product.name }}" title="{{ product.name }}" class="img-responsive" />
            {% if product.additional_image %}
            <img class="hover-img img-responsive" alt="{{ product.name }}" title="{{ product.name }}" src="{{ product.additional_image }}" />
            {% endif %}
          </a>

          <div class="exbutton-group">
            <button class="btn cartbtn" type="button" data-toggle="tooltip" title="{{ button_cart }}" onclick="cart.add('{{ product.product_id }}');"><i class="fa fa-shopping-cart"></i></button>
            <button class="btn wishbtn" type="button" data-toggle="tooltip" title="{{ button_wishlist }}" onclick="wishlist.add('{{ product.product_id }}');"><i class="fa fa-heart"></i></button>
            <button class="btn combtn" type="button" data-toggle="tooltip" title="{{ button_compare }}" onclick="compare.add('{{ product.product_id }}');"><i class="fa fa-exchange"></i></button>
          </div>
        </div>
        <div class="caption">
          <h4><a href="{{ product.href }}">{{ product.name }}</a></h4>
          <div class="rating">{% for i in 1..5 %}
            {% if product.rating < i %} <span class="fa fa-stack"><i class="fa fa-star-o fa-stack-2x"></i></span> {% else %} <span class="fa fa-stack"><i class="fa fa-star fa-stack-2x"></i><i class="fa fa-star-o fa-stack-2x"></i></span> {% endif %}
            {% endfor %}</div>
          {% if product.price %}
          <p class="price"> {% if not product.special %}
            {{ product.price }}
            {% else %} <span class="price-new">{{ product.special }}</span> <span class="price-old">{{ product.price }}</span> {% endif %}
            {% if product.tax %} <span class="price-tax">{{ text_tax }} {{ product.tax }}</span> {% endif %} </p>
          {% endif %} </div>

      </div>
    </div>
    {% endfor %}
  </div>
</div>