<?php
// Heading
$_['heading_title']    = 'ES Circlet Theme';

// Text
$_['text_extension']   = 'Extensions';
$_['text_success']     = 'Success: You have modified ES-Circlet Theme.';
$_['text_edit']        = 'Edit ES-Circlet Theme';

// Tab
$_['tab_general']		= 'General';

// Entry
$_['entry_status']     	= 'Status';
$_['entry_banner']     	= 'Banner Image';

// Error
$_['error_warning']		= 'Warning: Please check the form carefully for errors!';
$_['error_permission'] 	= 'Warning: You do not have permission to modify ES-Circlet Theme!';