<?php
// Heading
$_['heading_title']			= 'Custom Footer';

// Text
$_['text_extension']   		= 'Extensions';
$_['text_success']     		= 'Success: You have modified custom footer!';
$_['text_edit']        		= 'Edit Custom Footer';
$_['text_control_panel']    = 'Extension Setting';

// Tab
$_['tab_general']				= 'Control Panel';
$_['tab_colors']				= 'Colors';
$_['tab_support']				= 'Support';

// Entry
$_['entry_status']     			= 'Status';
$_['entry_logo']     			= 'Display Logo';
$_['entry_bgcolor']				= 'Background Color';
$_['entry_heading_color']		= 'heading_color';
$_['entry_bgcolor']								= 'Background Color';
$_['entry_heading_color']						= 'Heading Text Color';
$_['entry_icon_color']							= 'Icon Color';
$_['entry_text_color']							= 'Text Color';
$_['entry_link_hover_color']					= 'Link Hover Color';
$_['entry_social_media_bgcolor']				= 'Socialmedia Background Color';
$_['entry_social_media_color']					= 'Socialmedia Color';
$_['entry_social_media_hover_bgcolor']			= 'Socialmedia Hover Background Color';
$_['entry_social_media_hover_color']			= 'Socialmedia Hover Color';
$_['entry_newsletter_btn_bg']					= 'Newsletter Button Background Color';
$_['entry_newsletter_btn_color']				= 'Newsletter Button Text Color';
$_['entry_newsletter_input_border_color']		= 'Newsletter Input Border Color';
$_['entry_hot_line_color']						= 'Hot Line Color';

// Error
$_['error_permission'] 		= 'Warning: You do not have permission to modify custom footer!';